# prc02u.py (encoding: utf-8)
  # 統計Rの table() による集計結果をpython側で表示
  # 身長区分のみの集計、身長区分×性別のクロス集計を行う
  # クロス集計表の Excelファイルへの書き出しも行う
import pandas as pd
from rpy2.robjects import r
from textwrap import dedent
import xlwt
import pyrcmd as prc
prc.set_charset('utf-8')

src_file = 'data.csv'
rscript = dedent(u'''\
    dtf <- read.csv("%s", header=T, na.string="", fileEncoding="%s")
    dtf$性別 <- factor(dtf$性別, levels=c("男性", "女性", NA),
      labels=c("男性", "女性", "記載なし"), exclude=NULL)
    clevels <- c("155未満", "155～165", "165～175", "175以上")
    cc <- cut(dtf$身長, breaks=c(-Inf, 155, 165, 175, Inf),
        labels=clevels, right=FALSE)
    cc <- factor(cc, levels=c(clevels, NA),
      labels=c(clevels, "不明"), exclude=NULL)
    dtf <- cbind(dtf, 身長区分=cc)
    tbl1 <- table(dtf$身長区分)
    tbl2 <- table(dtf$身長区分, dtf$性別)
    ''') % (src_file, prc.get_charset(src_file))
prc.rexec(rscript, sink=False)  # Rコマンドの実行
tbl1 = r['tbl1']  # rp2オブジェクトとして取得
tbl2 = r['tbl2']
ptbl1 = prc.rp2pd(tbl1)  # pandasオブジェクトに変換
ptbl2 = prc.rp2pd(tbl2)

print(u'＊身長区分の集計結果')
print(ptbl1)
print('')
print(u'＊身長区分×性別の集計結果')
print(ptbl2)
    # ptbl2をExcelに出力
writer = pd.ExcelWriter("prc02u.xls")
ptbl2.to_excel(writer, startrow=1, startcol=0)
worksheet = writer.sheets['Sheet1']
worksheet.write(0, 0,  # 引数は row, column の順番
  u"身長区分×性別の集計表")
writer.save()
